# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Module-Runtime
Version:	0.016
Release:	19.%{__distinit}%{__distvers}
Summary:	Runtime module handling
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Module-Runtime
Source0:	https://cpan.metacpan.org/modules/by-module/Module/Module-Runtime-%{version}.tar.gz
BuildArch:	noarch
# Build:
BuildRequires:	coreutils
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(Module::Build)
# Module:
# (none)
# Tests:
BuildRequires:	perl(Test::More) >= 0.41
BuildRequires:	perl(Test::Pod) >= 1.00
BuildRequires:	perl(Test::Pod::Coverage)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
The functions exported by this module deal with runtime handling of Perl
modules, which are normally handled at compile time.

%prep
%setup -q -n Module-Runtime-%{version}

%build
perl Build.PL --installdirs=vendor
./Build

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%{_fixperms} -c %{buildroot}

%check
./Build test

%files
%doc Changes README
%{perl_vendorlib}/Module/
%{_mandir}/man3/Module::Runtime.3*

%changelog
* Fri Jul 14 2023 Paul Howarth <paul@city-fan.org> - 0.016-19
- Use SPDX-format license tag

* Thu Jun  6 2019 Paul Howarth <paul@city-fan.org> - 0.016-6
- Perl 5.30 rebuild

* Wed Oct 18 2017 Paul Howarth <paul@city-fan.org> - 0.016-1
- Update to 0.016
  - Port t/taint.t to Perl 5.27.5, where re-requiring an already-loaded
    module doesn't trigger tainting
  - Skip t/taint.t if the perl empirically doesn't perform taint checks but
    the script got run anyway (which happens with an unsupported configuration
    of the Perl core that some people are using in the absence of a supported
    no-taint configuration)
  - In t/taint.t, use $^X rather than $ENV{PATH} as the primordial tainted
    value to taint a string being tested
  - In documentation, use four-column indentation for all verbatim material
  - In META.{yml,json}, point to public bug tracker
  - In META.json, specify type of public repository

* Mon Jul 17 2017 Paul Howarth <paul@city-fan.org> - 0.015-1
- Update to 0.015
  - Update test suite not to rely on . in @INC, which is no longer necessarily
    there from Perl 5.25.7
  - In documentation, warn about the security problem with
    use_package_optimistically()
  - Declare correct version for Test::More dependency
  - Generate "traditional" style of compatibility Makefile.PL, to permit
    building in environments that don't support Build.PL or configure_requires
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Tue Sep  6 2016 Paul Howarth <paul@city-fan.org> - 0.014-8
- BR: perl-generators where available

* Sun Aug 31 2014 Paul Howarth <paul@city-fan.org> - 0.014-3
- Drop %%defattr, redundant since rpm 4.4

* Fri Feb  7 2014 Paul Howarth <paul@city-fan.org> - 0.014-1
- Update to 0.014:
  - Bugfix: suppress any CORE::GLOBAL::require override, where possible, to
    avoid use_package_optimistically() being misled into treating missing
    modules as broken
  - Bugfix: in use_module() and use_package_optimistically(), pass a supplied
    VERSION parameter through for the version check even if it is undef
  - Tighten use_package_optimistically()'s recognition of can't-locate errors
    (the same way that base.pm has recently been tightened), so that, when a
    module fails to load because a module that it uses isn't available, the
    outer module will be perceived as broken rather than missing
  - Update documentation notes about the state of Unicode handling for module
    names
  - In META.{yml,json}, point to public git repository

* Fri Jun 29 2012 Paul Howarth <paul@city-fan.org> - 0.013-2
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions priot to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Don't need to run test suite with LC_ALL=C

* Fri Feb 17 2012 Paul Howarth <paul@city-fan.org> - 0.013-1
- Update to 0.013:
  - Fix false failure of the test for lack of unintended dependencies
    that occurred on systems using a sitecustomize.pl (CPAN RT#75001)

* Sun Feb 12 2012 Paul Howarth <paul@city-fan.org> - 0.012-1
- Update to 0.012:
  - Work around Perl core bug (Perl RT#68590) regarding leakage of %%^H into
    modules being loaded
  - Work around Perl core bug that made a failed module loading appear
    successful when re-requiring the same module
  - Duplicate is_string() from Params::Classify, rather than importing it,
    to avoid circular dependency problems
  - Duplicate minimal exporting behaviour from Exporter, and avoid using the
    "feature", "warnings", "strict", and "parent" pragmata, to allow for
    possible future use of this module by any infrastructure module
  - Document core bug workarounds
  - Document module name syntax more prominently, and discuss the state of
    Unicode handling
  - Tweak documentation of use_package_optimistically()
  - Test behaviour with tainted module name
  - Test lack of unwanted eval frame around require
  - Give test modules more meaningful names
- Drop now-redundant dependencies on perl(Exporter), perl(Params::Classify)
  and perl(parent)
- BR: perl(strict) and perl(warnings) for test suite

* Tue Oct 25 2011 Paul Howarth <paul@city-fan.org> - 0.011-1
- Update to 0.011:
  - Bugfix: in require_module() and use_module(), work around a Perl core bug
    affecting Perl 5.8 and 5.10 that could pass the wrong context to the file
    scope of a required file, which breaks some modules; this bug would only
    rarely afflict the core's require() in situations where it would afflict
    require_module()

* Fri Oct  7 2011 Paul Howarth <paul@city-fan.org> - 0.010-1
- Update to 0.010:
  - Bugfix: in use_package_optimistically(), fix regexp interpolation that
    broke operation if the module was loaded from a path containing
    metacharacters

* Wed Oct  5 2011 Paul Howarth <paul@city-fan.org> - 0.009-1
- Import from Fedora
- Update to 0.009:
  - New function module_notional_filename()
  - Simplify behaviour of use_package_optimistically() to match simplified
    base.pm 2.18

* Fri Jul 22 2011 Petr Sabata <contyk@redhat.com> - 0.008-2
- Perl mass rebuild

* Mon Jul 11 2011 Petr Pisar <ppisar@redhat.com> - 0.008-1
- Specfile autogenerated by cpanspec 1.78
